==> foundation-2.6.1.tgz: package/Map/Map.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Map = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M91.967 7.961c0-.016.005-.031.005-.047a2.733 2.733 0 00-2.73-2.733H39.559v.011L8.031 36.721h-.003v55.365h.003v.001a2.735 2.735 0 002.734 2.731h78.479a2.73 2.73 0 002.663-2.15h.06v-.536c0-.015.004-.029.004-.044s-.004-.029-.004-.044V7.961zm-24.328 7.177H82.01v24.597L63.897 21.621l3.742-6.483zM39.57 39.453v-.001a2.732 2.732 0 002.722-2.73V15.138H61.88l-27.17 47.06-16.725-16.725v-6.02H39.57zM17.985 84.862V52.527L32.128 66.67 21.626 84.862h-3.641zm9.4 0l33.93-58.769 20.696 20.696v38.073H27.385z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M62.03 45.576c-6.645 0-12.026 5.387-12.026 12.027 0 2.659.873 5.109 2.334 7.1l7.759 13.439c.047.094.097.186.157.271l.016.027.004-.002a2.16 2.16 0 003.405.132l.02.011.075-.129a2.25 2.25 0 00.287-.497l7.608-13.178a11.962 11.962 0 002.39-7.175c-.003-6.639-5.384-12.026-12.029-12.026zM61.911 63.7a5.924 5.924 0 01-5.926-5.925 5.926 5.926 0 115.926 5.925z"
  }));
});
Map.displayName = 'Map';
export const MapDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Map/Map.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Map = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M91.967 7.961c0-.016.005-.031.005-.047a2.733 2.733 0 00-2.73-2.733H39.559v.011L8.031 36.721h-.003v55.365h.003v.001a2.735 2.735 0 002.734 2.731h78.479a2.73 2.73 0 002.663-2.15h.06v-.536c0-.015.004-.029.004-.044s-.004-.029-.004-.044V7.961zm-24.328 7.177H82.01v24.597L63.897 21.621l3.742-6.483zM39.57 39.453v-.001a2.732 2.732 0 002.722-2.73V15.138H61.88l-27.17 47.06-16.725-16.725v-6.02H39.57zM17.985 84.862V52.527L32.128 66.67 21.626 84.862h-3.641zm9.4 0l33.93-58.769 20.696 20.696v38.073H27.385z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M62.03 45.576c-6.645 0-12.026 5.387-12.026 12.027 0 2.659.873 5.109 2.334 7.1l7.759 13.439c.047.094.097.186.157.271l.016.027.004-.002a2.16 2.16 0 003.405.132l.02.011.075-.129a2.25 2.25 0 00.287-.497l7.608-13.178a11.962 11.962 0 002.39-7.175c-.003-6.639-5.384-12.026-12.029-12.026zM61.911 63.7a5.924 5.924 0 01-5.926-5.925 5.926 5.926 0 115.926 5.925z"
  }));
});
Map.displayName = 'Map';
export var MapDimensions = {
  height: 100,
  width: 100
};
